@@ -6,7 +6,7 @@
 Mednafen's Neo Geo Pocket emulation is based off of <a href="http://neopop.emuxhaven.net/">NeoPop</a>.
 <p>
 The Neo Geo Pocket (Color) emulation in Mednafen is not very accurate in terms of low-level details; BIOS is HLE'd, CPU instruction
-timing is totally fubared, some CPU instructions are likely emulated incorrectly, and there are a couple of per-game hacks.
+timing is totally fubared, and some CPU instructions are likely emulated incorrectly.
 It's sufficient to play most of the commercially released games fairly well, but if you want to do NGP(C) homebrew development,
 you're better off at looking at something like <a href="http://www.mess.org">M.E.S.S.</a>.
 </p>
@@ -33,15 +33,6 @@ you're better off at looking at something like <a href="http://www.mess.org">M.E
  </table>
 <?php EndSection(); ?>
 
-
-<?php BeginSection('Game-specific Emulation Hacks'); ?>
- <table border width="100%">
-  <tr><th>Title:</th><th>Description:</th><th>Source code files affected:</th></tr>
-  <tr><td>Metal Slug - 2nd Mission</td><td>Patch to work around lack of one of the side effects of a real BIOS(to be fixed in a future version of Mednafen).</td><td>src/ngp/rom.cpp</td></tr>
-  <tr><td>Puyo Pop</td><td></td><td>src/ngp/rom.cpp</td></tr>
-  </table>
-<?php EndSection(); ?>
-
 <?php PrintSettings(); ?>
 
 <?php EndPage(); ?>
