@@ -3,11 +3,14 @@
 <?php BeginPage('psx', 'Sony PlayStation'); ?>
 
 <?php BeginSection('Introduction', "", FALSE, FALSE, "Section_intro"); ?>
-PlayStation 1 emulation is currently in a state of development.  Save states, rewinding, and netplay are not currently supported.
+<p>
+<font color="red" size="+2">WARNING:</font> Save states(and by extension, state rewinding and netplay) and saved games on emulated memory cards do not mix well unless you are
+extremely careful.  For any given game, either use save states or the game's own save system, but not both, lest you may destroy your saved games.
+</p>
 <p>
 A dual-core Phenom II or Athlon II at 3GHz or higher, or rough equivalent(in terms of single-core IPC), is recommended for
-running Mednafen's PlayStation 1 emulation on.  For better performance, the binary should be compiled for a 64-bit
-target(for example, x86_64) rather than 32-bit, if available.<br>
+running Mednafen's PlayStation 1 emulation on(note that this recommendation does not apply to any unofficial ports or forks, which may have higher
+CPU requirements).  For better performance, the binary should be compiled for a 64-bit target(for example, x86_64) rather than 32-bit, if available.<br>
 </p>
 
 <p>
@@ -16,7 +19,12 @@ avoid short emulator pauses and audio pops due to waiting for disk accesses to c
 </p>
 
 <p>
-<a href="http://www.neillcorlett.com/psf/">PSF1</a> playback is supported.
+<a href="http://www.neillcorlett.com/psf/">PSF1</a> playback is supported.  However, many PSF1 rips won't work as they are broken in various ways:
+<ul>
+ <li>Contain malformed PS-EXE headers.
+ <li>Perform unaligned halfword and word memory accesses.
+ <li>Erroneously use load instruction target register as a source register in load delay slots.
+</ul>
 </p>
 
 <?php EndSection(); ?>
@@ -24,18 +32,18 @@ avoid short emulator pauses and audio pops due to waiting for disk accesses to c
 
 <?php BeginSection("Firmware/BIOS", "", FALSE, FALSE, "Section_firmware_bios"); ?>
 <p>
-Place the correct BIOS image files in the <a href="mednafen.html#Section_firmware_bios">correct location</a>.  <b>DO NOT</b> rename other revisions/regions of the BIOS to match the expected filenames, or you'll likely
-cause emulation glitches.
+Place the correct BIOS image files in the <a href="mednafen.html#Section_firmware_bios">correct location</a>.  Do not rename other revisions/regions of the BIOS to match the expected filenames, or you'll likely
+cause emulation glitches(and cause confusion if you ever distribute or otherwise refer to these misnamed files).
 </p>
 
 <p>
 The filenames listed below are per default psx.bios_* settings.
 </p>
 <table border>
- <tr><th>Filename:</th><th>Purpose:</th></tr>
- <tr><td>scph5500.bin</td><td>SCPH-5500 BIOS image.  Required for Japan-region games.</td></tr>
- <tr><td>scph5501.bin</td><td>SCPH-5501 BIOS image.  Required for North America/US-region games.  Reportedly the same as the SCPH-7003 BIOS image.</td></tr>
- <tr><td>scph5502.bin</td><td>SCPH-5502 BIOS image.  Required for Europe-region games.</td></tr>
+ <tr><th>Filename:</th><th>Purpose:</th><th>Hash:</tr>
+ <tr><td>scph5500.bin</td><td><b>SCPH-5500</b>/v<b>3.0J</b> BIOS image.<br>Required for Japan-region games.</td><td><b><u>MD5:</u></b> 8dd7d5296a650fac7319bce665a6a53c<br><b><u>SHA256:</u></b> 9c0421858e217805f4abe18698afea8d5aa36ff0727eb8484944e00eb5e7eadb</td></tr>
+ <tr><td>scph5501.bin</td><td><b>SCPH-5501</b>/v<b>3.0A</b> BIOS image.<br>Required for North America/US-region games.<br>Reportedly the same as the SCPH-7003 BIOS image.</td><td><b><u>MD5:</u></b> 490f666e1afb15b7362b406ed1cea246<br><b><u>SHA256:</u></b> 11052b6499e466bbf0a709b1f9cb6834a9418e66680387912451e971cf8a1fef</td></tr>
+ <tr><td>scph5502.bin</td><td><b>SCPH-5502</b>/v<b>3.0E</b> BIOS image.<br>Required for Europe-region games.</td><td><b><u>MD5:</b></u> 32736f17079d0b2b7024407c39bd3050<br><b><u>SHA256:</u></b> 1faaa18fa820a0225e488d9f086296b8e6c46df739666093987ff7d8fd352c09</td></tr>
 </table>
 <?php EndSection(); ?>
 
@@ -111,6 +119,35 @@ is enabled when running them.
 </p>
 <?php EndSection(); ?>
 
+<?php BeginSection('Default Input Mappings'); ?>
+
+ <?php BeginSection('Digital Gamepad on Virtual Port 1'); ?>
+  <p>
+  <table border>
+   <tr><th>Key:</th><th nowrap>Emulated Button:</th></tr>
+
+   <tr><td>W</td><td>Up</td></tr>
+   <tr><td>S</td><td>Down</td></tr>
+   <tr><td>A</td><td>Left</td></tr>
+   <tr><td>D</td><td>Right</td></tr>
+
+   <tr><td>Tab</td><td>SELECT</td></tr>
+   <tr><td>Enter</td><td>START</td></tr>
+
+   <tr><td>Keypad 8</td><td>△</td></tr>
+   <tr><td>Keypad 2</td><td>x</td></tr>
+   <tr><td>Keypad 4</td><td>□</td></tr>
+   <tr><td>Keypad 6</td><td>○</td></tr>
+
+   <tr><td>Keypad 1</td><td>L1</td></tr>
+   <tr><td>Keypad 7</td><td>L2</td></tr>
+   <tr><td>Keypad 3</td><td>R1</td></tr>
+   <tr><td>Keypad 9</td><td>R2</td></tr>
+  </table>
+  </p>
+ <?php EndSection(); ?>
+
+<?php EndSection(); ?>
 
 <?php PrintSettings(); ?>
 
