@@ -3,7 +3,7 @@
 <?php BeginPage('snes', 'Super Nintendo Entertainment System/Super Famicom'); ?>
 
 <?php BeginSection('Introduction'); ?>
-SNES emulation is based off of <a href="http://byuu.org/">bsnes</a> v0.059, with the following (unofficial) modifications:
+Mednafen's SNES emulation is a fork of <a href="http://byuu.org/">bsnes</a> v0.059, with(but not limited to) the following modifications:
 <ul>
  <li>Cx4 Op10 fix patch</li>
  <li>blargg_libco_ppc64-5</li>
@@ -17,6 +17,9 @@ SNES emulation is based off of <a href="http://byuu.org/">bsnes</a> v0.059, with
 SNSF playback is supported to a degree; however, its implementation in Mednafen is incomplete.
 </p>
 <p>
+SPC playback is not supported, but it is supported (experimentally) by the <b><a href="snes_faust.html">snes_faust</a></b> module.
+</p>
+<p>
 <b><font color="red">WARNING:</font></b> Saving state(and by extension rewinding and netplay) with Mednafen's SNES emulation may break some games.
 "Tales of Phantasia" is a known problematic game in this regard.
 </p>
@@ -46,6 +49,18 @@ SNSF playback is supported to a degree; however, its implementation in Mednafen
  </table>
  </p>
 
+ <p>
+ <table border>
+  <tr><th colspan="2">Virtual Super Scope</th></tr>
+  <tr><th>Key:</th><th nowrap>Button:</th></tr>
+  <tr><td>Mouse Left</td><td>Trigger</td></tr>
+  <tr><td>Mouse Right</td><td>Cursor</td></tr>
+  <tr><td>Mouse Middle</td><td>Pause</td></tr>
+  <tr><td>End</td><td>Turbo</td></tr>
+  <tr><td>Space</td><td>Offscreen Shot(Simulated)</td></tr>
+ </table>
+ </p>
+
 
 <?php EndSection(); ?>
 
